@@ -113,14 +113,14 @@ module LogStash
 
       require "fileutils"
       # create Gemfile from template iff it does not exist
-      unless ::File.exists?(Environment::GEMFILE_PATH)
+      unless ::File.exist?(Environment::GEMFILE_PATH)
         FileUtils.copy(
           ::File.join(Environment::LOGSTASH_HOME, "Gemfile.template"), Environment::GEMFILE_PATH
         )
       end
       # create Gemfile.jruby-1.9.lock from template iff a template exists it itself does not exist
-      lock_template = ::File.join(ENV["LOGSTASH_HOME"], "Gemfile.jruby-2.6.lock.release")
-      if ::File.exists?(lock_template) && !::File.exists?(Environment::LOCKFILE)
+      lock_template = ::File.join(ENV["LOGSTASH_HOME"], "Gemfile.jruby-3.1.lock.release")
+      if ::File.exist?(lock_template) && !::File.exist?(Environment::LOCKFILE)
         FileUtils.copy(lock_template, Environment::LOCKFILE)
       end
 
@@ -143,7 +143,6 @@ module LogStash
                 "BUNDLE_GEMFILE" => LogStash::Environment::GEMFILE_PATH,
                 "BUNDLE_SILENCE_ROOT_WARNING" => "true",
                 "BUNDLE_WITHOUT" => options[:without].join(":")}) do
-
         if !debug?
           # Will deal with transient network errors
           execute_bundler_with_retry(options)
@@ -163,7 +162,7 @@ module LogStash
           begin
             execute_bundler(options)
             break
-          rescue ::Bundler::SolveFailure => e
+          rescue ::Bundler::VersionConflict => e
             $stderr.puts("Plugin version conflict, aborting")
             raise(e)
           rescue ::Bundler::GemNotFound => e
@@ -193,8 +192,8 @@ module LogStash
       ::Bundler::CLI.start(bundler_arguments(options))
     end
 
-    def specific_platforms(platforms=::Gem.platforms)
-      platforms.find_all {|plat| plat.is_a?(::Gem::Platform) && plat.os=='java' && !plat.cpu.nil?}
+    def specific_platforms(platforms = ::Gem.platforms)
+      platforms.find_all {|plat| plat.is_a?(::Gem::Platform) && plat.os == 'java' && !plat.cpu.nil?}
     end
 
     def genericize_platform
@@ -234,7 +233,7 @@ module LogStash
     # @return [Array] gem names that plugin depends on
     def fetch_plugin_dependencies(plugin_name)
       old_spec = ::Gem::Specification.find_all_by_name(plugin_name).last
-      require_version = old_spec ? ">= #{old_spec.version}": nil
+      require_version = old_spec ? ">= #{old_spec.version}" : nil
       dep = ::Gem::Dependency.new(plugin_name, require_version)
       new_specs, errors = ::Gem::SpecFetcher.fetcher.spec_for_dependency(dep)
 
@@ -311,6 +310,5 @@ module LogStash
     ensure
       $stdout = old_stdout
     end
-
   end
 end
