@@ -19,7 +19,6 @@ require "rubygems/package"
 require "yaml"
 
 module LogStash::PluginManager
-
   def self.load_aliases_definitions(path = File.expand_path('plugin_aliases.yml', __dir__))
     content = IO.read(path)
 
@@ -57,8 +56,7 @@ module LogStash::PluginManager
   # @param [Hash] options the options used to setup external components
   # @option options [Array<String>] :rubygems_source Gem sources to lookup for the verification
   # @return [Boolean] true if valid logstash plugin gem name & version or a .gem file
-  def self.logstash_plugin?(plugin, version = nil, options={})
-
+  def self.logstash_plugin?(plugin, version = nil, options = {})
     if plugin_file?(plugin)
       begin
         return logstash_plugin_gem_spec?(plugin_file_spec(plugin))
@@ -68,7 +66,7 @@ module LogStash::PluginManager
         return false
       end
     else
-      dep = ::Gem::Dependency.new(plugin, version || ::Gem::Requirement.default)
+      dep = _gem_dependency(plugin, version)
       ::Gem.sources = ::Gem::SourceList.from(options[:rubygems_source]) if options[:rubygems_source]
       specs, errors = ::Gem::SpecFetcher.fetcher.spec_for_dependency(dep)
 
@@ -89,13 +87,19 @@ module LogStash::PluginManager
     end
   end
 
+  # This test injection point allows us to avoid mocking the ::Gem::Dependency
+  # that is used by ruby internals for finding dependencies on the load path
+  def self._gem_dependency(gem_name, version = nil)
+    ::Gem::Dependency.new(gem_name, version || ::Gem::Requirement.default)
+  end
+
   # Fetch latest version information as in rubygems
   # @param [String] The plugin name
   # @param [Hash] Set of available options when fetching the information
   # @option options [Boolean] :pre Include pre release versions in the search (default: false)
   # @return [Hash] The plugin version information as returned by rubygems
-  def self.fetch_latest_version_info(plugin, options={})
-    exclude_prereleases =  options.fetch(:pre, false)
+  def self.fetch_latest_version_info(plugin, options = {})
+    exclude_prereleases = options.fetch(:pre, false)
     versions = LogStash::Rubygems.versions(plugin)
     raise ValidationError.new("Something went wrong with the validation. You can skip the validation with the --no-verify option") if !versions.is_a?(Array) || versions.empty?
     versions = versions.select { |version| !version["prerelease"] } if !exclude_prereleases
@@ -126,7 +130,7 @@ module LogStash::PluginManager
   # @return [Array<Gem::Specification>] all local logstash plugin gem specs
   def self.find_plugins_gem_specs(name = nil)
     specs = name ? ::Gem::Specification.find_all_by_name(name) : ::Gem::Specification.find_all
-    specs.select{|spec| logstash_plugin_gem_spec?(spec)}
+    specs.select {|spec| logstash_plugin_gem_spec?(spec)}
   end
 
   # list of all locally installed plugins specs specified in the Gemfile.
@@ -137,7 +141,7 @@ module LogStash::PluginManager
   def self.all_installed_plugins_gem_specs(gemfile)
     # we start form the installed gemspecs so we can verify the metadata for valid logstash plugin
     # then filter out those not included in the Gemfile
-    find_plugins_gem_specs.select{|spec| !!gemfile.find(spec.name)}
+    find_plugins_gem_specs.select {|spec| !!gemfile.find(spec.name)}
   end
 
   # @param plugin [String] plugin name
@@ -174,7 +178,6 @@ module LogStash::PluginManager
   # @param plugin_list [Array] array of [plugin name, version] tuples
   # @return [Array] array of [plugin name, version, ...] tuples when duplicate names have been merged and non duplicate version requirements added
   def self.merge_duplicates(plugin_list)
-
     # quick & dirty naive dedup for now
     # TODO: properly merge versions requirements
     plugin_list.uniq(&:first)
