@@ -1,4 +1,20 @@
-# encoding: utf-8
+# Licensed to Elasticsearch B.V. under one or more contributor
+# license agreements. See the NOTICE file distributed with
+# this work for additional information regarding copyright
+# ownership. Elasticsearch B.V. licenses this file to you under
+# the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#  http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 require "logstash/api/commands/base"
 require 'logstash/util/thread_dump'
 require 'logstash/config/pipelines_info'
@@ -19,10 +35,12 @@ module LogStash
             type = p_stats[:queue] && p_stats[:queue][:type].value
             pipeline = service.agent.get_pipeline(pipeline_id)
             next if pipeline.nil? || pipeline.system? || type != 'persisted'
-            total_queued_events += p_stats[:queue][:events].value
+            total_queued_events += p_stats.dig(:queue, :events)&.value || 0
           end
 
           {:events_count => total_queued_events}
+        rescue LogStash::Instrument::MetricStore::MetricNotFound
+          {}
         end
 
         def jvm
@@ -58,9 +76,22 @@ module LogStash
             [:stats, :events],
             :in, :filtered, :out, :duration_in_millis, :queue_push_duration_in_millis
           )
+        rescue LogStash::Instrument::MetricStore::MetricNotFound
+          # if the stats/events metrics have not yet been populated, return an empty map
+          {}
         end
 
-        def pipeline(pipeline_id = nil, opts={})
+        def flow
+          extract_metrics(
+            [:stats, :flow],
+            :input_throughput, :filter_throughput, :output_throughput, :queue_backpressure, :worker_concurrency
+          )
+        rescue LogStash::Instrument::MetricStore::MetricNotFound
+          # if the stats/events metrics have not yet been populated, return an empty map
+          {}
+        end
+
+        def pipeline(pipeline_id = nil, opts = {})
           extended_stats = LogStash::Config::PipelinesInfo.format_pipelines_info(
             service.agent,
             service.snapshot.metric_store,
@@ -112,12 +143,18 @@ module LogStash
           service.get_shallow(:jvm, :gc)
         end
 
-        def hot_threads(options={})
+        def hot_threads(options = {})
           HotThreadsReport.new(self, options)
         end
 
+        def geoip
+          service.get_shallow(:geoip_download_manager)
+        rescue
+          {}
+        end
+
         private
-        def plugins_stats_report(pipeline_id, extended_pipeline, opts={})
+        def plugins_stats_report(pipeline_id, extended_pipeline, opts = {})
           stats = service.get_shallow(:stats, :pipelines, pipeline_id.to_sym)
           PluginsStats.report(stats, extended_pipeline, opts)
         end
@@ -135,9 +172,10 @@ module LogStash
             end
           end
 
-          def report(stats, extended_stats=nil, opts={})
+          def report(stats, extended_stats = nil, opts = {})
             ret = {
               :events => stats[:events],
+              :flow => stats[:flow],
               :plugins => {
                 :inputs => plugin_stats(stats, :inputs),
                 :codecs => plugin_stats(stats, :codecs),
@@ -151,7 +189,7 @@ module LogStash
 
             # if extended_stats were provided, enrich the return value
             if extended_stats
-              ret[:queue]    = extended_stats["queue"] if extended_stats.include?("queue")
+              ret[:queue].merge!(extended_stats["queue"]) if extended_stats.include?("queue")
               ret[:hash] = extended_stats["hash"]
               ret[:ephemeral_id] = extended_stats["ephemeral_id"]
               if opts[:vertices] && extended_stats.include?("vertices")
@@ -169,7 +207,7 @@ module LogStash
           # @param vertex [Hash{String=>Object}]
           # @return [Hash{String=>Object}]
           def decorate_vertex(vertex)
-            plugin_id = vertex["id"]&.to_s
+            plugin_id = vertex[:id]&.to_s
             return vertex unless plugin_id && LogStash::PluginMetadata.exists?(plugin_id)
 
             plugin_metadata = LogStash::PluginMetadata.for_plugin(plugin_id)
