@@ -47,7 +47,6 @@ LogStash::Environment.load_locale!
 # }
 #
 module LogStash::Config::Mixin
-
   include LogStash::Util::SubstitutionVariables
   include LogStash::Util::Loggable
 
@@ -166,7 +165,6 @@ module LogStash::Config::Mixin
   end # def config_init
 
   module DSL
-
     include LogStash::Util::SubstitutionVariables
 
     attr_accessor :flags
@@ -201,7 +199,7 @@ module LogStash::Config::Mixin
     # @option opts [Boolean]      :list
     # @option opts [Object]       :default
     # @option opts [Boolean]      :required
-    def config(name, opts={})
+    def config(name, opts = {})
       @config ||= Hash.new
       # TODO(sissel): verify 'name' is of type String, Symbol, or Regexp
 
@@ -235,7 +233,7 @@ module LogStash::Config::Mixin
       # add any options from this class
       prefix = self.name.split("::").last.downcase
       @flags.each do |flag|
-        flagpart = flag[:args].first.gsub(/^--/,"")
+        flagpart = flag[:args].first.gsub(/^--/, "")
         # TODO(sissel): logger things here could help debugging.
 
         opts.on("--#{prefix}-#{flagpart}", *flag[:args][1..-1], &flag[:block])
@@ -566,7 +564,7 @@ module LogStash::Config::Mixin
               #return false, "Require absolute path, got relative path #{value.first}?"
             #end
 
-            if !File.exists?(value.first) # Check if the file exists
+            if !File.exist?(value.first) # Check if the file exists
               return false, "File does not exist or cannot be opened #{value.first}"
             end
 
@@ -595,7 +593,7 @@ module LogStash::Config::Mixin
 
             return [false, "Expected a hex-encoded SHA-256 fingerprint, got `#{candidate.inspect}`"] unless candidate.kind_of?(String) && candidate =~ /\A(?:[[:xdigit:]]{2}:?){32}\z/
 
-            return [true, candidate.upcase.tr('^0-9A-F','')]
+            return [true, candidate.upcase.tr('^0-9A-F', '')]
           else
             return false, "Unknown validator symbol #{validator}"
         end # case validator
