@@ -1,4 +1,20 @@
-# encoding: utf-8
+# Licensed to Elasticsearch B.V. under one or more contributor
+# license agreements. See the NOTICE file distributed with
+# this work for additional information regarding copyright
+# ownership. Elasticsearch B.V. licenses this file to you under
+# the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#  http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 require "logstash/instrument/periodic_poller/base"
 require "logstash/instrument/periodic_poller/load_average"
 require "logstash/environment"
@@ -16,7 +32,6 @@ java_import 'javax.naming.directory.Attribute'
 java_import 'org.logstash.instrument.reports.MemoryReport'
 java_import 'org.logstash.instrument.reports.ProcessReport'
 
-
 module LogStash module Instrument module PeriodicPoller
   class JVM < Base
     class GarbageCollectorName
@@ -29,7 +44,7 @@ module LogStash module Instrument module PeriodicPoller
       def self.get(gc_name)
         if YOUNG_GC_NAMES.include?(gc_name)
           YOUNG
-        elsif(OLD_GC_NAMES.include?(gc_name))
+        elsif (OLD_GC_NAMES.include?(gc_name))
           OLD
         end
       end
@@ -102,7 +117,6 @@ module LogStash module Instrument module PeriodicPoller
       metric.gauge(cpu_path, :total_in_millis, cpu_metrics["total_in_millis"])
 
       metric.gauge(path + [:mem], :total_virtual_in_bytes, process_metrics["mem"]["total_virtual_in_bytes"])
-
     end
 
     def collect_load_average
@@ -125,7 +139,7 @@ module LogStash module Instrument module PeriodicPoller
 
     def collect_heap_metrics(data)
       heap = aggregate_information_for(data["heap"].values)
-      heap[:used_percent] = (heap[:used_in_bytes] / heap[:max_in_bytes].to_f)*100.0
+      heap[:used_percent] = (heap[:used_in_bytes] / heap[:max_in_bytes].to_f) * 100.0
 
       heap.each_pair do |key, value|
         metric.gauge([:jvm, :memory, :heap], key, value.to_i)
@@ -135,14 +149,14 @@ module LogStash module Instrument module PeriodicPoller
     def collect_non_heap_metrics(data)
       non_heap = aggregate_information_for(data["non_heap"].values)
       non_heap.each_pair do |key, value|
-        metric.gauge([:jvm, :memory, :non_heap],key, value.to_i)
+        metric.gauge([:jvm, :memory, :non_heap], key, value.to_i)
       end
     end
 
     def collect_pools_metrics(data)
       metrics = build_pools_metrics(data)
       metrics.each_pair do |key, hash|
-        hash.each_pair do |p,v|
+        hash.each_pair do |p, v|
           metric.gauge([:jvm, :memory, :pools, key.to_sym], p, v)
         end
       end
@@ -153,12 +167,15 @@ module LogStash module Instrument module PeriodicPoller
       old  = {}
       old = old.merge!(heap["CMS Old Gen"]) if heap.has_key?("CMS Old Gen")
       old = old.merge!(heap["PS Old Gen"])  if heap.has_key?("PS Old Gen")
+      old = old.merge!(heap["G1 Old Gen"])  if heap.has_key?("G1 Old Gen")
       young = {}
       young = young.merge!(heap["Par Eden Space"]) if heap.has_key?("Par Eden Space")
       young = young.merge!(heap["PS Eden Space"])  if heap.has_key?("PS Eden Space")
+      young = young.merge!(heap["G1 Eden Space"])  if heap.has_key?("G1 Eden Space")
       survivor = {}
       survivor = survivor.merge!(heap["Par Survivor Space"]) if heap.has_key?("Par Survivor Space")
       survivor = survivor.merge!(heap["PS Survivor Space"])  if heap.has_key?("PS Survivor Space")
+      survivor = survivor.merge!(heap["G1 Survivor Space"])  if heap.has_key?("G1 Survivor Space")
       {
         "young"    => aggregate_information_for(young),
         "old"      => aggregate_information_for(old),
@@ -167,9 +184,9 @@ module LogStash module Instrument module PeriodicPoller
     end
 
     def aggregate_information_for(collection)
-      collection.reduce(default_information_accumulator) do |m,e|
+      collection.reduce(default_information_accumulator) do |m, e|
         e = { e[0] => e[1] } if e.is_a?(Array)
-        e.each_pair do |k,v|
+        e.each_pair do |k, v|
           if MEMORY_TRANSPOSE_MAP.include?(k)
             transpose_key = MEMORY_TRANSPOSE_MAP[k]
             m[transpose_key] += v
