@@ -22,7 +22,7 @@ $DEBUGLIST = (ENV["DEBUG"] || "").split(",")
 require 'pathname'
 LogStash::ROOT = Pathname.new(File.join(File.expand_path(File.dirname(__FILE__)), "..", "..", "..")).cleanpath.to_s
 LogStash::XPACK_PATH = File.join(LogStash::ROOT, "x-pack")
-LogStash::OSS = ENV["OSS"] == "true" || !File.exists?(LogStash::XPACK_PATH)
+LogStash::OSS = ENV["OSS"] == "true" || !File.exist?(LogStash::XPACK_PATH)
 
 if !LogStash::OSS
   xpack_dir = File.join(LogStash::XPACK_PATH, "lib")
@@ -162,13 +162,13 @@ class LogStash::Runner < Clamp::StrictCommand
     :default => LogStash::SETTINGS.get_default('pipeline.ecs_compatibility')
 
   # Data Path Setting
-  option ["--path.data"] , "PATH",
+  option ["--path.data"], "PATH",
     I18n.t("logstash.runner.flag.datapath"),
     :attribute_name => "path.data",
     :default => LogStash::SETTINGS.get_default("path.data")
 
   # Plugins Settings
-  option ["-p", "--path.plugins"] , "PATH",
+  option ["-p", "--path.plugins"], "PATH",
     I18n.t("logstash.runner.flag.pluginpath"),
     :multivalued => true, :attribute_name => "path.plugins",
     :default => LogStash::SETTINGS.get_default("path.plugins")
@@ -305,7 +305,7 @@ class LogStash::Runner < Clamp::StrictCommand
       logger.warn("--config.debug was specified, but log.level was not set to \'debug\'! No config info will be logged.")
     end
 
-    while(msg = LogStash::DeprecationMessage.instance.shift)
+    while (msg = LogStash::DeprecationMessage.instance.shift)
       deprecation_logger.deprecated msg
     end
 
@@ -336,7 +336,7 @@ class LogStash::Runner < Clamp::StrictCommand
 
     field_reference_escape_style_setting = settings.get_setting('config.field_reference.escape_style')
     if field_reference_escape_style_setting.set?
-      logger.warn(I18n.t("logstash.settings.technical_preview.set", canonical_name: field_reference_escape_style_setting.name))
+      logger.warn(I18n.t("logstash.settings.technical_preview.set", :canonical_name => field_reference_escape_style_setting.name))
     end
     field_reference_escape_style = field_reference_escape_style_setting.value
     logger.debug("Setting global FieldReference escape style: #{field_reference_escape_style}")
@@ -368,7 +368,6 @@ class LogStash::Runner < Clamp::StrictCommand
 
     configure_plugin_paths(setting("path.plugins"))
 
-
     @settings.format_settings.each {|line| logger.debug(line) }
 
     # Check for absence of any configuration
@@ -441,7 +440,6 @@ class LogStash::Runner < Clamp::StrictCommand
     org.apache.logging.log4j.LogManager.shutdown
 
     agent_return
-
   rescue org.logstash.LockException => e
     logger.fatal(I18n.t("logstash.runner.locked-data-path", :path => setting("path.data")))
     return 1
